# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][clog], and this project adheres to [Semantic Versioning][semver].

## [Unreleased]

## [1.1.0] - 2020-08-31
### Added
- Add support for python 3.6

## [1.0.1] - 2019-11-21
### Fixed
- Fixed some typos

## [1.0.0] - 2019-11-14
### Added
- Added currency ISO codes (ISO-4217)
- Added country ISO codes (ISO-3166)


[unreleased]: https://github.com/spapanik/teritorio/compare/v1.1.0...master
[1.0.1]: https://github.com/spapanik/teritorio/compare/v1.0.1...v1.1.0
[1.0.1]: https://github.com/spapanik/teritorio/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/spapanik/teritorio/releases/tag/v1.0.0

[clog]: https://keepachangelog.com/en/1.0.0/
[semver]: https://semver.org/spec/v2.0.0.html
